:mod:`pylons.i18n.translation` -- Translation/Localization functions
====================================================================

.. automodule:: pylons.i18n.translation

Module Contents
---------------

.. autoexception:: LanguageError
.. autoclass:: LazyString
.. autofunction:: lazify
.. autofunction:: gettext_noop
.. autofunction:: gettext
.. autofunction:: ugettext
.. autofunction:: ngettext
.. autofunction:: ungettext
.. autofunction:: set_lang
.. autofunction:: get_lang
.. autofunction:: add_fallback
